@@ -22,16 +22,28 @@
  *  $Id: 
  */
 
+#if !defined (__EPHY_EPIPHANY_H_INSIDE__) && !defined (EPIPHANY_COMPILATION)
+#error "Only <epiphany/epiphany.h> can be included directly."
+#endif
+
 #ifndef EPHY_EMBED_UTILS_H
 #define EPHY_EMBED_UTILS_H
 
-#include "ephy-embed.h"
+#include "ephy-web-view.h"
+
+#include <webkit/webkit.h>
 
 G_BEGIN_DECLS
 
-char 	   * ephy_embed_utils_link_message_parse  (char *message);
-const char * ephy_embed_utils_get_title_composite (EphyEmbed *embed);
-gboolean     ephy_embed_utils_address_has_web_scheme (const char *address);
+#define EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED(embed) (WEBKIT_WEB_VIEW (ephy_embed_get_web_view (embed)))
+#define EPHY_GET_EMBED_FROM_EPHY_WEB_VIEW(view) (EPHY_EMBED (gtk_widget_get_parent (gtk_widget_get_parent (GTK_WIDGET (view)))))
+
+#define EPHY_WEBKIT_BACK_FORWARD_LIMIT 100
+
+char*    ephy_embed_utils_link_message_parse     (char       *message);
+gboolean ephy_embed_utils_address_has_web_scheme (const char *address);
+char*    ephy_embed_utils_normalize_address      (const char *address);
+gboolean ephy_embed_utils_url_is_empty           (const char *location);
 
 G_END_DECLS
 
