@@ -20,7 +20,6 @@
 #include "config.h"
 
 #include "ephy-gui.h"
-#include "eel-gconf-extensions.h"
 #include "ephy-stock-icons.h"
 #include "ephy-debug.h"
 
@@ -46,7 +45,7 @@ ephy_gui_sanitise_popup_position (GtkMenu *menu,
 
 	g_return_if_fail (widget != NULL);
 
-	gtk_widget_size_request (GTK_WIDGET (menu), &req);
+	gtk_widget_get_preferred_size (GTK_WIDGET (menu), &req, NULL);
 
 	monitor_num = gdk_screen_get_monitor_at_point (screen, *x, *y);
 	gtk_menu_set_monitor (menu, monitor_num);
@@ -72,7 +71,7 @@ ephy_gui_menu_position_tree_selection (GtkMenu   *menu,
 	GtkAllocation allocation;
 	GdkRectangle visible;
 
-	gtk_widget_size_request (GTK_WIDGET (menu), &req);
+	gtk_widget_get_preferred_size (GTK_WIDGET (menu), &req, NULL);
 	gdk_window_get_origin (gtk_widget_get_window (widget), x, y);
 	gtk_widget_get_allocation (widget, &allocation);
 
@@ -134,8 +133,8 @@ ephy_gui_menu_position_under_widget (GtkMenu   *menu,
 	container = gtk_widget_get_ancestor (widget, GTK_TYPE_CONTAINER);
 	g_return_if_fail (container != NULL);
 
-	gtk_widget_size_request (widget, &req);
-	gtk_widget_size_request (GTK_WIDGET (menu), &menu_req);
+	gtk_widget_get_preferred_size (widget, &req, NULL);
+	gtk_widget_get_preferred_size (GTK_WIDGET (menu), &menu_req, NULL);
 
 	screen = gtk_widget_get_screen (GTK_WIDGET (menu));
 	window = gtk_widget_get_window (widget);
@@ -203,8 +202,8 @@ ephy_gui_menu_position_on_toolbar (GtkMenu   *menu,
 	toolbar = GTK_TOOLBAR (gtk_widget_get_ancestor (widget, GTK_TYPE_TOOLBAR));
 	g_return_if_fail (toolbar != NULL);
 
-	gtk_widget_size_request (widget, &req);
-	gtk_widget_size_request (GTK_WIDGET (menu), &menu_req);
+	gtk_widget_get_preferred_size (widget, &req, NULL);
+	gtk_widget_get_preferred_size (GTK_WIDGET (menu), &menu_req, NULL);
 
 	screen = gtk_widget_get_screen (GTK_WIDGET (menu));
 	window = gtk_widget_get_window (widget);
@@ -506,20 +505,3 @@ ephy_gui_message_dialog_get_content_box (GtkWidget *dialog)
 
 	return container;
 }
-
-static void
-checkbutton_toggled_cb (GtkToggleButton *button,
-			const char *pref)
-{
-	eel_gconf_set_boolean (pref, gtk_toggle_button_get_active (button));
-}
-
-void
-ephy_gui_connect_checkbutton_to_gconf (GtkWidget *widget,
-				       const char *pref)
-{
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget),
-				      eel_gconf_get_boolean (pref));
-	g_signal_connect (widget, "toggled",
-			  G_CALLBACK (checkbutton_toggled_cb), (gpointer) pref);
-}
