@@ -476,7 +476,7 @@ entry_key_press_cb (GtkEntry *entry,
 {
 	guint state = event->state & gtk_accelerator_get_default_mod_mask ();
 
-	if (event->keyval == GDK_Escape && state == 0)
+	if (event->keyval == GDK_KEY_Escape && state == 0)
 	{
 		ephy_location_entry_reset_internal (lentry, TRUE);
 		/* don't return TRUE since we want to cancel the autocompletion popup too */
@@ -494,9 +494,9 @@ entry_key_press_after_cb (GtkEntry *entry,
 
 	guint state = event->state & gtk_accelerator_get_default_mod_mask ();
 
-	if ((event->keyval == GDK_Return ||
-	     event->keyval == GDK_KP_Enter ||
-	     event->keyval == GDK_ISO_Enter) &&
+	if ((event->keyval == GDK_KEY_Return ||
+	     event->keyval == GDK_KEY_KP_Enter ||
+	     event->keyval == GDK_KEY_ISO_Enter) &&
 	    (state == GDK_CONTROL_MASK ||
 	     state == (GDK_CONTROL_MASK | GDK_SHIFT_MASK)))
 	{
@@ -508,7 +508,7 @@ entry_key_press_after_cb (GtkEntry *entry,
 		return TRUE;
 	}
 	
-	if ((event->keyval == GDK_Down || event->keyval == GDK_KP_Down)
+	if ((event->keyval == GDK_KEY_Down || event->keyval == GDK_KEY_KP_Down)
 	    && state == 0)
 	{
 		/* If we are focusing the entry, with the cursor at the end of it
@@ -734,26 +734,30 @@ each_url_get_data_binder (EphyDragEachSelectedItemDataGet iteratee,
 	g_free (title);
 }
 
-#define DRAG_ICON_LAYOUT_BORDER		2
-#define DRAG_ICON_ICON_SPACING		DRAG_ICON_LAYOUT_BORDER * 2
+#define DRAG_ICON_LAYOUT_PADDING	2
+#define DRAG_ICON_ICON_PADDING		4
 #define DRAG_ICON_MAX_WIDTH_CHARS	32
 
-static GdkPixmap *
-favicon_create_drag_pixmap (EphyLocationEntry *entry,
-			    GtkWidget *widget)
+static cairo_surface_t *
+favicon_create_drag_surface (EphyLocationEntry *entry,
+			     GtkWidget *widget)
 {
 	EphyLocationEntryPrivate *priv = entry->priv;
 	char *title = NULL, *address = NULL;
 	GString *text;
 	GtkStyle *style;
-	GdkDrawable *drawable;
+	cairo_surface_t *surface;
 	PangoContext *context;
 	PangoLayout  *layout;
 	PangoFontMetrics *metrics;
-	int pixmap_height, pixmap_width;
+	int surface_height, surface_width;
 	int layout_width, layout_height;
-	int icon_width = 0, icon_height = 0, offset_x = 0;
+	int icon_width = 0, icon_height = 0, favicon_offset_x = 0;
 	int char_width;
+	cairo_t *cr;
+	GtkStateType state;
+
+	state = gtk_widget_get_state (widget);
 
 	g_signal_emit (entry, signals[GET_LOCATION], 0, &address);
 	g_signal_emit (entry, signals[GET_TITLE], 0, &title);
@@ -774,8 +778,6 @@ favicon_create_drag_pixmap (EphyLocationEntry *entry,
 		g_string_append (text, address);
 	}
 
-	/* Now build the pixmap */
-
 	if (priv->favicon != NULL)
 	{
 		icon_width = gdk_pixbuf_get_width (priv->favicon);
@@ -785,7 +787,6 @@ favicon_create_drag_pixmap (EphyLocationEntry *entry,
 	context = gtk_widget_get_pango_context (widget);
 	layout = pango_layout_new (context);
 
-	context = gtk_widget_get_pango_context (widget);
 	style = gtk_widget_get_style (widget);
 	metrics = pango_context_get_metrics (context,
 					     style->font_desc,
@@ -798,66 +799,59 @@ favicon_create_drag_pixmap (EphyLocationEntry *entry,
 	pango_layout_set_width (layout, char_width * DRAG_ICON_MAX_WIDTH_CHARS);
 	pango_layout_set_text (layout, text->str, text->len);
 
-	pango_layout_get_size (layout, &layout_width, &layout_height);
-
-	pixmap_width  = layout_width  / PANGO_SCALE + DRAG_ICON_LAYOUT_BORDER * 2;
+	pango_layout_get_pixel_size (layout, &layout_width, &layout_height);
 
 	if (priv->favicon != NULL)
 	{
-		offset_x = icon_width + 2 * DRAG_ICON_ICON_SPACING;
-		pixmap_width += offset_x;
-		pixmap_height = MAX (layout_height / PANGO_SCALE, icon_height) + DRAG_ICON_LAYOUT_BORDER * 2;
-	}
-	else
-	{
-		pixmap_height = layout_height / PANGO_SCALE + DRAG_ICON_LAYOUT_BORDER * 2;
+		favicon_offset_x = icon_width + (2 * DRAG_ICON_ICON_PADDING);
 	}
 
-	drawable = gdk_pixmap_new (gtk_widget_get_window (widget),
-				   pixmap_width  + 2,
-				   pixmap_height + 2,
-				   -1);
+	surface_width = layout_width + favicon_offset_x +
+			(DRAG_ICON_LAYOUT_PADDING * 2);
+	surface_height = MAX (layout_height, icon_height) +
+			(DRAG_ICON_LAYOUT_PADDING * 2);
 
-	gdk_draw_rectangle (drawable,
-			    style->base_gc [gtk_widget_get_state (widget)],
-			    TRUE,
-			    0, 0,
-			    pixmap_width + 1,
-			    pixmap_height + 1);
+	surface = gdk_window_create_similar_surface (gtk_widget_get_window (widget),
+						     CAIRO_CONTENT_COLOR,
+						     surface_width + 2,
+						     surface_height + 2);
+	cr = cairo_create (surface);
 
+	cairo_rectangle (cr, 1, 1, surface_width, surface_height);
+	cairo_set_line_width (cr, 1.0);
+
+	cairo_set_source_rgb (cr, 0.0, 0.0, 0.0);
+	cairo_stroke_preserve (cr);
+
+	gdk_cairo_set_source_color (cr, &style->bg[state]);
+	cairo_fill (cr);
 
 	if (priv->favicon != NULL)
 	{
-		gdk_draw_pixbuf (drawable,
-				 style->fg_gc[gtk_widget_get_state (widget)],
-				 priv->favicon,
-				 0, 0, 
-				 1 + DRAG_ICON_LAYOUT_BORDER + DRAG_ICON_ICON_SPACING,
-				 1 + DRAG_ICON_LAYOUT_BORDER + (pixmap_height - icon_height) / 2,
-				 -1, -1,
-				 GDK_RGB_DITHER_NONE, 0, 0);
+		double x;
+		double y;
+
+		x = 1 + DRAG_ICON_LAYOUT_PADDING + DRAG_ICON_ICON_PADDING;
+		y = 1 + DRAG_ICON_LAYOUT_PADDING + (surface_height - icon_height) / 2;
+		gdk_cairo_set_source_pixbuf (cr, priv->favicon, x, y);
+		cairo_rectangle (cr, x, y, icon_width, icon_height);
+		cairo_fill (cr);
 	}
 
-	gdk_draw_layout (drawable,
-			 style->text_gc [gtk_widget_get_state (widget)],
-			 1 + DRAG_ICON_LAYOUT_BORDER + offset_x,
-			 1 + DRAG_ICON_LAYOUT_BORDER,
-			 layout);
-
-	gdk_draw_rectangle (drawable,
-			    style->black_gc,
-			    FALSE,
-			    0, 0,
-			    pixmap_width + 1,
-			    pixmap_height + 1);
+	cairo_move_to (cr,
+		       1 + DRAG_ICON_LAYOUT_PADDING + favicon_offset_x,
+		       1 + DRAG_ICON_LAYOUT_PADDING);
+	gdk_cairo_set_source_color (cr, &style->text[state]);
+	pango_cairo_show_layout (cr, layout);
 
+	cairo_destroy (cr);
 	g_object_unref (layout);
 
 	g_free (address);
 	g_free (title);
-	g_string_free (text,TRUE);
+	g_string_free (text, TRUE);
 
-	return drawable;
+	return surface;
 }
 
 static void
@@ -865,7 +859,7 @@ favicon_drag_begin_cb (GtkWidget *widget,
 		       GdkDragContext *context,
 		       EphyLocationEntry *lentry)
 {
-	GdkPixmap *pixmap;
+	cairo_surface_t *surface;
 	GtkEntry *entry;
 	gint index;
 
@@ -875,14 +869,12 @@ favicon_drag_begin_cb (GtkWidget *widget,
 	if (index != GTK_ENTRY_ICON_PRIMARY)
 		return;
 
-	pixmap = favicon_create_drag_pixmap (lentry, widget);
+	surface = favicon_create_drag_surface (lentry, widget);
 
-	if (pixmap != NULL)
+	if (surface != NULL)
 	{
-		gtk_drag_set_icon_pixmap (context,
-					  gdk_drawable_get_colormap (pixmap),
-					  pixmap, NULL, -2, -2);
-		g_object_unref (pixmap);
+		gtk_drag_set_icon_surface (context, surface);
+		cairo_surface_destroy (surface);
 	}
 }
 
