@@ -16,19 +16,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id$
  */
 
 #include "config.h"
 
-#include <gtk/gtktreeselection.h>
-#include <gtk/gtktreeviewcolumn.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkcellrendererpixbuf.h>
-#include <gtk/gtkcellrenderertoggle.h>
-#include <gtk/gtktreemodelfilter.h>
-#include <gtk/gtkwindow.h>
-#include <gtk/gtkmain.h>
+#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
 #include "ephy-node-view.h"
@@ -39,6 +31,14 @@
 #include "ephy-marshal.h"
 #include <string.h>
 
+/**
+ * SECTION:ephy-node-view
+ * @short_description: A #GtkTreeView displaying a collection of #EphyNode elements.
+ *
+ * #EphyNodeView implements a #GtkTreeView displaying a given set of #EphyNode
+ * elements. It implements drag and dropping.
+ */
+
 static void ephy_node_view_class_init (EphyNodeViewClass *klass);
 static void ephy_node_view_init (EphyNodeView *view);
 static void ephy_node_view_finalize (GObject *object);
@@ -73,10 +73,10 @@ struct _EphyNodeViewPrivate
 	gboolean drag_started;
 	int drag_button;
 	int drag_x;
-        int drag_y;
+	int drag_y;
 	GtkTargetList *source_target_list;
 
-	gboolean drop_occurred;                                                                                          
+	gboolean drop_occurred;
 	gboolean have_drag_data;
 	GtkSelectionData *drag_data;
 	guint scroll_id;
@@ -191,11 +191,11 @@ gtk_tree_view_vertical_autoscroll (GtkTreeView *tree_view)
 	float value;
 	
 	window = gtk_tree_view_get_bin_window (tree_view);
-	vadjustment = gtk_tree_view_get_vadjustment (tree_view);
+	vadjustment = gtk_scrollable_get_vadjustment (GTK_SCROLLABLE (tree_view));
 	
 	gdk_window_get_pointer (window, NULL, &y, NULL);
 	
-	y += vadjustment->value;
+	y += gtk_adjustment_get_value (vadjustment);
 
 	gtk_tree_view_get_visible_rect (tree_view, &visible_rect);
 	
@@ -209,8 +209,8 @@ gtk_tree_view_vertical_autoscroll (GtkTreeView *tree_view)
 		}
 	}
 
-	value = CLAMP (vadjustment->value + offset, 0.0,
-		       vadjustment->upper - vadjustment->page_size);
+	value = CLAMP (gtk_adjustment_get_value (vadjustment) + offset, 0.0,
+		       gtk_adjustment_get_upper (vadjustment) - gtk_adjustment_get_page_size (vadjustment));
 	gtk_adjustment_set_value (vadjustment, value);
 }
 
@@ -321,7 +321,7 @@ drag_motion_cb (GtkWidget *widget,
 		    priority != EPHY_NODE_VIEW_SPECIAL_PRIORITY &&
 		    ephy_node_get_is_drag_source (node))
 		{
-			action = context->suggested_action;
+			action = gdk_drag_context_get_suggested_action (context);
 		}
 	}
 	
@@ -379,7 +379,8 @@ drag_data_received_cb (GtkWidget *widget,
 
 	/* x and y here are valid only on drop ! */
 
-	if (selection_data->length <= 0 || selection_data->data == NULL)
+	if ((gtk_selection_data_get_length (selection_data) <= 0) ||
+	    (gtk_selection_data_get_data (selection_data) == NULL))
 	{
 		return;
 	}	
@@ -451,6 +452,15 @@ drag_drop_cb (GtkWidget *widget,
 	return TRUE;
 }
 
+/**
+ * ephy_node_view_enable_drag_dest:
+ * @view: the #EphyNodeView
+ * @types: types allowed as #GtkTargetEntry
+ * @n_types: count of @types
+ *
+ * Set the types of drag destination allowed by @view.
+ *
+ **/
 void
 ephy_node_view_enable_drag_dest (EphyNodeView *view,
 				 const GtkTargetEntry *types,
@@ -482,23 +492,25 @@ filter_changed_cb (EphyNodeFilter *filter,
 		   EphyNodeView *view)
 {
 	GtkWidget *window;
+	GdkWindow *gdk_window;
 
 	g_return_if_fail (EPHY_IS_NODE_VIEW (view));
 
 	window = gtk_widget_get_toplevel (GTK_WIDGET (view));
+	gdk_window = gtk_widget_get_window (window);
 
-	if (window != NULL && window->window != NULL)
+	if (window != NULL && gdk_window != NULL)
 	{
 		/* nice busy cursor */
 		GdkCursor *cursor;
 
 		cursor = gdk_cursor_new (GDK_WATCH);
-		gdk_window_set_cursor (window->window, cursor);
+		gdk_window_set_cursor (gdk_window, cursor);
 		gdk_cursor_unref (cursor);
 
 		gdk_flush ();
 
-		gdk_window_set_cursor (window->window, NULL);
+		gdk_window_set_cursor (gdk_window, NULL);
 
 		/* no flush: this will cause the cursor to be reset
 		 * only when the UI is free again */
@@ -510,7 +522,7 @@ filter_changed_cb (EphyNodeFilter *filter,
 
 static void
 ephy_node_view_selection_changed_cb (GtkTreeSelection *selection,
-			             EphyNodeView *view)
+				     EphyNodeView *view)
 {
 	EphyNodeViewPrivate *priv = view->priv;
 	GList *list;
@@ -531,9 +543,9 @@ ephy_node_view_selection_changed_cb (GtkTreeSelection *selection,
 
 static void
 ephy_node_view_row_activated_cb (GtkTreeView *treeview,
-			         GtkTreePath *path,
-			         GtkTreeViewColumn *column,
-			         EphyNodeView *view)
+				 GtkTreePath *path,
+				 GtkTreeViewColumn *column,
+				 EphyNodeView *view)
 {
 	GtkTreeIter iter, iter2;
 	EphyNode *node;
@@ -599,10 +611,10 @@ ephy_node_view_key_press_cb (GtkTreeView *treeview,
 {
 	gboolean handled = FALSE;
 
-	if (event->keyval == GDK_space ||
-	    event->keyval == GDK_Return ||
-	    event->keyval == GDK_KP_Enter ||
-	    event->keyval == GDK_ISO_Enter)
+	if (event->keyval == GDK_KEY_space ||
+	    event->keyval == GDK_KEY_Return ||
+	    event->keyval == GDK_KEY_KP_Enter ||
+	    event->keyval == GDK_KEY_ISO_Enter)
 	{
 		if (view->priv->toggle_column >= 0)
 		{
@@ -625,11 +637,11 @@ selection_foreach (GtkTreeModel *model,
 		   gpointer data)
 {
 	GList **list;
-                                                                                                                              
+
 	list = (GList**)data;
-                                                                                                                              
+
 	*list = g_list_prepend (*list,
-				gtk_tree_row_reference_new (model, path));              
+				gtk_tree_row_reference_new (model, path));
 }
 
 static GList *
@@ -642,21 +654,21 @@ get_selection_refs (GtkTreeView *tree_view)
 	gtk_tree_selection_selected_foreach (selection,
 					     selection_foreach,
 					     &ref_list);
-	ref_list = g_list_reverse (ref_list);                                                                                                                              
+	ref_list = g_list_reverse (ref_list);
 	return ref_list;
 }
-                                                                                                                              
+
 static void
 ref_list_free (GList *ref_list)
 {
-        g_list_foreach (ref_list, (GFunc) gtk_tree_row_reference_free, NULL);
-        g_list_free (ref_list);
+	g_list_foreach (ref_list, (GFunc) gtk_tree_row_reference_free, NULL);
+	g_list_free (ref_list);
 }
-                                                                                                                              
+
 static void
 stop_drag_check (EphyNodeView *view)
 {
-        view->priv->drag_button = 0;
+	view->priv->drag_button = 0;
 }
 
 static gboolean
@@ -667,32 +679,32 @@ button_event_modifies_selection (GdkEventButton *event)
 
 static void
 did_not_drag (EphyNodeView *view,
-              GdkEventButton *event)
+	      GdkEventButton *event)
 {
-        GtkTreeView *tree_view;
-        GtkTreeSelection *selection;
-        GtkTreePath *path;
-                                                                                                                              
-        tree_view = GTK_TREE_VIEW (view);
-        selection = gtk_tree_view_get_selection (tree_view);
-                                                                                                                              
-        if (gtk_tree_view_get_path_at_pos (tree_view, event->x, event->y,
-                                           &path, NULL, NULL, NULL))
+	GtkTreeView *tree_view;
+	GtkTreeSelection *selection;
+	GtkTreePath *path;
+
+	tree_view = GTK_TREE_VIEW (view);
+	selection = gtk_tree_view_get_selection (tree_view);
+
+	if (gtk_tree_view_get_path_at_pos (tree_view, event->x, event->y,
+					   &path, NULL, NULL, NULL))
 	{
-                if((event->button == 1 || event->button == 2) &&
-                   gtk_tree_selection_path_is_selected (selection, path) &&
-                   !button_event_modifies_selection (event))
+		if((event->button == 1 || event->button == 2) &&
+		   gtk_tree_selection_path_is_selected (selection, path) &&
+		   !button_event_modifies_selection (event))
 		{
 			if (gtk_tree_selection_get_mode (selection) == GTK_SELECTION_MULTIPLE)
 			{
-	                        gtk_tree_selection_unselect_all (selection);
+				gtk_tree_selection_unselect_all (selection);
 			}
 
-                        gtk_tree_selection_select_path (selection, path);
-                }
-                                                                                                                              
-                gtk_tree_path_free (path);
-        }                                                                                                              
+			gtk_tree_selection_select_path (selection, path);
+		}
+
+		gtk_tree_path_free (path);
+	}
 }
 
 typedef struct
@@ -733,27 +745,27 @@ can_drag_selection (EphyNodeView *view)
 
 static void
 drag_data_get_cb (GtkWidget *widget,
-                  GdkDragContext *context,
-                  GtkSelectionData *selection_data,
-                  guint info,
-                  guint time)
+		  GdkDragContext *context,
+		  GtkSelectionData *selection_data,
+		  guint info,
+		  guint time)
 {
 	GtkTreeView *tree_view;
 	GtkTreeModel *model;
 	GList *ref_list;
-                                                                                                                              
+
 	tree_view = GTK_TREE_VIEW (widget);
-                                                                                                                              
+
 	model = gtk_tree_view_get_model (tree_view);
 	g_return_if_fail (model != NULL);
-                                                                                                                              
+
 	ref_list = g_object_get_data (G_OBJECT (context), "drag-info");
-                                                                                                                              
+
 	if (ref_list == NULL)
 	{
-        	return;
+		return;
 	}
-                                                                                                                              
+
 	if (EGG_IS_TREE_MULTI_DRAG_SOURCE (model))
 	{
 		egg_tree_multi_drag_source_drag_data_get (EGG_TREE_MULTI_DRAG_SOURCE (model),
@@ -764,20 +776,20 @@ drag_data_get_cb (GtkWidget *widget,
 
 static gboolean
 button_release_cb (GtkWidget *widget,
-                   GdkEventButton *event,
-                   EphyNodeView *view)
+		   GdkEventButton *event,
+		   EphyNodeView *view)
 {
-        if (event->button == view->priv->drag_button)
+	if (event->button == view->priv->drag_button)
 	{
 		stop_drag_check (view);
 		if (!view->priv->drag_started)
 		{
-                        did_not_drag (view, event);
-                        return TRUE;
-                }
+			did_not_drag (view, event);
+			return TRUE;
+		}
 		view->priv->drag_started = FALSE;
-        }
-        return FALSE;
+	}
+	return FALSE;
 }
 
 static gboolean
@@ -785,25 +797,25 @@ motion_notify_cb (GtkWidget *widget,
 		  GdkEventMotion *event,
 		  EphyNodeView *view)
 {
-        GdkDragContext *context;
-        GList *ref_list;
-                                                                                                      
+	GdkDragContext *context;
+	GList *ref_list;
+
 	if (event->window != gtk_tree_view_get_bin_window (GTK_TREE_VIEW (widget)))
 	{
 		return FALSE;
-	}                                                                                                                      
-        if (view->priv->drag_button != 0)
+	}
+	if (view->priv->drag_button != 0)
 	{
 		if (gtk_drag_check_threshold (widget, view->priv->drag_x,
-                                              view->priv->drag_y, event->x,
+					      view->priv->drag_y, event->x,
 					      event->y)
 		    && can_drag_selection (view))
 		{
 			context = gtk_drag_begin
 				(widget, view->priv->source_target_list,
-                                 GDK_ACTION_ASK | GDK_ACTION_COPY | GDK_ACTION_LINK,
-                                 view->priv->drag_button,
-                                 (GdkEvent*)event);
+				 GDK_ACTION_ASK | GDK_ACTION_COPY | GDK_ACTION_LINK,
+				 view->priv->drag_button,
+				 (GdkEvent*)event);
 
 			stop_drag_check (view);
 			view->priv->drag_started = TRUE;
@@ -823,8 +835,8 @@ motion_notify_cb (GtkWidget *widget,
 
 static gboolean
 ephy_node_view_button_press_cb (GtkWidget *treeview,
-			        GdkEventButton *event,
-			        EphyNodeView *view)
+				GdkEventButton *event,
+				EphyNodeView *view)
 {
 	GtkTreePath *path = NULL;
 	GtkTreeSelection *selection;
@@ -855,11 +867,11 @@ ephy_node_view_button_press_cb (GtkWidget *treeview,
 		}
 
 		if(!button_event_modifies_selection (event) &&
-                   event->button == 1 && path_is_selected &&
+		   event->button == 1 && path_is_selected &&
 		   gtk_tree_selection_count_selected_rows (selection) > 1)
 		{
-                        call_parent = FALSE;
-                }
+			call_parent = FALSE;
+		}
 
 		if (call_parent)
 		{
@@ -890,10 +902,10 @@ ephy_node_view_button_press_cb (GtkWidget *treeview,
 			{
 				view->priv->drag_started = FALSE;
 				view->priv->drag_button = event->button;
-		                view->priv->drag_x = event->x;
-		                view->priv->drag_y = event->y;
+				view->priv->drag_x = event->x;
+				view->priv->drag_y = event->y;
 			}
-	        }
+		}
 
 		gtk_tree_path_free (path);
 	}
@@ -920,7 +932,7 @@ ephy_node_view_set_filter (EphyNodeView *view, EphyNodeFilter *filter)
 	{
 		view->priv->filter = g_object_ref (filter);
 		g_signal_connect_object (G_OBJECT (view->priv->filter),
-				         "changed", G_CALLBACK (filter_changed_cb),
+					 "changed", G_CALLBACK (filter_changed_cb),
 					 G_OBJECT (view), 0);
 	}
 
@@ -975,6 +987,16 @@ ephy_node_view_get_property (GObject *object,
 	}
 }
 
+/**
+ * ephy_node_view_new:
+ * @root: the root #EphyNode for the view
+ * @filter: a filter model for the view
+ *
+ * Creates a new #EphyNodeView using @filter as the model and @root as the root
+ * node.
+ *
+ * Returns: a new #EphyNodeView as a #GtkWidget
+ **/
 GtkWidget *
 ephy_node_view_new (EphyNode *root,
 		    EphyNodeFilter *filter)
@@ -993,9 +1015,9 @@ ephy_node_view_new (EphyNode *root,
 
 static void
 cell_renderer_edited (GtkCellRendererText *cell,
-                      const char *path_str,
-                      const char *new_text,
-                      EphyNodeView *view)
+		      const char *path_str,
+		      const char *new_text,
+		      EphyNodeView *view)
 {
 	GtkTreePath *path;
 	GtkTreeIter iter, iter2;
@@ -1004,8 +1026,8 @@ cell_renderer_edited (GtkCellRendererText *cell,
 	view->priv->edited_node = NULL;
 
 	g_object_set (G_OBJECT (view->priv->editable_renderer),
-                      "editable", FALSE,
-                      NULL);
+		      "editable", FALSE,
+		      NULL);
 
 	path = gtk_tree_path_new_from_string (path_str);
 	gtk_tree_model_get_iter (view->priv->sortmodel, &iter, path);
@@ -1025,7 +1047,7 @@ cell_renderer_edited (GtkCellRendererText *cell,
 
 static void
 renderer_editing_canceled_cb (GtkCellRendererText *cell,
-                              EphyNodeView *view)
+			      EphyNodeView *view)
 {
 	if (view->priv->remove_if_cancelled)
 	{
@@ -1037,33 +1059,33 @@ renderer_editing_canceled_cb (GtkCellRendererText *cell,
 static inline int
 compare_string_values (const GValue *a_value, const GValue *b_value)
 {
-        const char *str1, *str2;
-        int retval;
-                                                                                                                        
-        str1 = g_value_get_string (a_value);
-        str2 = g_value_get_string (b_value);                                                                                 
+	const char *str1, *str2;
+	int retval;
 
-        if (str1 == NULL)
-        {
-                retval = -1;
-        }
-        else if (str2 == NULL)
-        {
-                retval = 1;
-        }
-        else
-        {
-	        char *str_a;
-	        char *str_b;
+	str1 = g_value_get_string (a_value);
+	str2 = g_value_get_string (b_value);
 
-                str_a = g_utf8_casefold (str1, -1);
-                str_b = g_utf8_casefold (str2, -1);
-                retval = g_utf8_collate (str_a, str_b);
-                g_free (str_a);
-                g_free (str_b);
-        }
-                                                                                                              
-        return retval;
+	if (str1 == NULL)
+	{
+		retval = -1;
+	}
+	else if (str2 == NULL)
+	{
+		retval = 1;
+	}
+	else
+	{
+		char *str_a;
+		char *str_b;
+
+		str_a = g_utf8_casefold (str1, -1);
+		str_b = g_utf8_casefold (str2, -1);
+		retval = g_utf8_collate (str_a, str_b);
+		g_free (str_a);
+		g_free (str_b);
+	}
+
+	return retval;
 }
 
 static int
@@ -1206,11 +1228,24 @@ provide_text_weight (EphyNode *node, GValue *value, EphyNodeView *view)
 	}
 }
 
+/**
+ * ephy_node_view_add_data_column:
+ * @view: an #EphyNodeView
+ * @value_type: type to be held by the column
+ * @prop_id: property corresponding to the model behind @view
+ * @func: a data function for the column or %NULL
+ * @data: optional data for @func
+ *
+ * Adds a new column to @view, taking its value from a column in the model defined
+ * by @prop_id, or from @func.
+ *
+ * Returns: the id of the new column
+ **/
 int
 ephy_node_view_add_data_column (EphyNodeView *view,
-			        GType value_type,
+				GType value_type,
 				guint prop_id,
-			        EphyTreeModelNodeValueFunc func,
+				EphyTreeModelNodeValueFunc func,
 				gpointer data)
 {
 	int column;
@@ -1229,6 +1264,20 @@ ephy_node_view_add_data_column (EphyNodeView *view,
 	return column;
 }
 
+/**
+ * ephy_node_view_add_column:
+ * @view: an #EphyNodeView
+ * @title: title for the column
+ * @value_type: type to be held by the column
+ * @prop_id: numeric id corresponding to the column in the model to be shown
+ * @flags: flags for the new column
+ * @icon_func: a function providing the icon for the column
+ * @ret: location to store the created column
+ *
+ * Adds a new column, corresponding to a @prop_id of the model, to the @view.
+ *
+ * Returns: the id of the new column
+ **/
 int
 ephy_node_view_add_column (EphyNodeView *view,
 			   const char  *title,
@@ -1252,7 +1301,7 @@ ephy_node_view_add_column (EphyNodeView *view,
 	if (icon_func)
 	{
 		icon_column = ephy_tree_model_node_add_func_column
-	                 (view->priv->nodemodel, GDK_TYPE_PIXBUF, icon_func, NULL);
+			 (view->priv->nodemodel, GDK_TYPE_PIXBUF, icon_func, NULL);
 
 		renderer = gtk_cell_renderer_pixbuf_new ();
 		gtk_tree_view_column_pack_start (gcolumn, renderer, FALSE);
@@ -1328,8 +1377,15 @@ ephy_node_view_add_column (EphyNodeView *view,
 	return column;
 }
 
+/**
+ * ephy_node_view_set_priority:
+ * @view: an #EphyNodeView
+ * @priority_prop_id: one of #EphyNodeViewPriority
+ *
+ * Adds a priority column to the @view with @priority_prop_id as the value.
+ **/
 void
-ephy_node_view_set_priority (EphyNodeView *view, guint priority_prop_id)
+ephy_node_view_set_priority (EphyNodeView *view, EphyNodeViewPriority priority_prop_id)
 {
 	int priority_column;
 
@@ -1342,6 +1398,15 @@ ephy_node_view_set_priority (EphyNodeView *view, guint priority_prop_id)
 	view->priv->priority_prop_id = priority_prop_id;
 }
 
+/**
+ * ephy_node_view_set_sort:
+ * @view: an #EphyNodeView
+ * @value_type: type of the value held at @prop_id by the model
+ * @prop_id: column id in the model
+ * @sort_type: the sort mode
+ *
+ * Adds a sort column to the @view corresponding to @prop_id in the model.
+ **/
 void
 ephy_node_view_set_sort (EphyNodeView *view, GType value_type, guint prop_id,
 			 GtkSortType sort_type)
@@ -1391,6 +1456,14 @@ get_selection (GtkTreeModel *model,
 	*list = g_list_prepend (*list, node);
 }
 
+/**
+ * ephy_node_view_get_selection:
+ * @view: an #EphyNodeView
+ *
+ * Returns the selected elements of @view as a #GList of #EphyNode elements.
+ *
+ * Returns: a #GList of #EphyNode elements
+ **/
 GList *
 ephy_node_view_get_selection (EphyNodeView *view)
 {
@@ -1410,6 +1483,12 @@ ephy_node_view_get_selection (EphyNodeView *view)
 	return list;
 }
 
+/**
+ * ephy_node_view_remove:
+ * @view: an #EphyNodeView
+ *
+ * Remove the currently selected nodes from @view.
+ **/
 void
 ephy_node_view_remove (EphyNodeView *view)
 {
@@ -1483,6 +1562,13 @@ ephy_node_view_remove (EphyNodeView *view)
 	}
 }
 
+/**
+ * ephy_node_view_select_node:
+ * @view: an #EphyNodeView
+ * @node: the #EphyNode in the @view to be selected
+ *
+ * Puts the selection of @view on @node.
+ **/
 void
 ephy_node_view_select_node (EphyNodeView *view,
 			    EphyNode *node)
@@ -1502,12 +1588,22 @@ ephy_node_view_select_node (EphyNodeView *view,
 					&iter);
 }
 
+/**
+ * ephy_node_view_enable_drag_source:
+ * @view: an #EphyNodeView
+ * @types: a #GtkTargetEntry for the @view
+ * @n_types: length of @types
+ * @base_drag_column_id: id of the column for ephy_tree_model_sort_set_base_drag_column_id
+ * @extra_drag_column_id: id of the column for ephy_tree_model_sort_set_extra_drag_column_id
+ *
+ * Sets @view as a drag source.
+ **/
 void
 ephy_node_view_enable_drag_source (EphyNodeView *view,
 				   const GtkTargetEntry *types,
 				   int n_types,
-				   int base_drag_column,
-				   int extra_drag_column)
+				   int base_drag_column_id,
+				   int extra_drag_column_id)
 {
 	GtkWidget *treeview;
 
@@ -1519,27 +1615,35 @@ ephy_node_view_enable_drag_source (EphyNodeView *view,
 		gtk_target_list_new (types, n_types);
 
 	ephy_tree_model_sort_set_base_drag_column_id  (EPHY_TREE_MODEL_SORT (view->priv->sortmodel),
-					               base_drag_column);
+						       base_drag_column_id);
 	ephy_tree_model_sort_set_extra_drag_column_id (EPHY_TREE_MODEL_SORT (view->priv->sortmodel),
-					               extra_drag_column);
+						       extra_drag_column_id);
 
 	g_signal_connect_object (G_OBJECT (view),
-			         "button_release_event",
-			         G_CALLBACK (button_release_cb),
-			         view,
+				 "button_release_event",
+				 G_CALLBACK (button_release_cb),
+				 view,
 				 0);
 	g_signal_connect_object (G_OBJECT (view),
-			         "motion_notify_event",
-			         G_CALLBACK (motion_notify_cb),
-			         view,
+				 "motion_notify_event",
+				 G_CALLBACK (motion_notify_cb),
+				 view,
 				 0);
 	g_signal_connect_object (G_OBJECT (view),
-			         "drag_data_get",
-			         G_CALLBACK (drag_data_get_cb),
-			         view,
+				 "drag_data_get",
+				 G_CALLBACK (drag_data_get_cb),
+				 view,
 				 0);
 }
 
+/**
+ * ephy_node_view_edit:
+ * @view: an #EphyNodeView
+ * @remove_if_cancelled: whether the edited node should be removed if editing is cancelled
+ *
+ * Edits the currently selected node in @view, the @remove_if_cancelled parameter
+ * controls if the node should be removed if editing is cancelled.
+ **/
 void
 ephy_node_view_edit (EphyNodeView *view, gboolean remove_if_cancelled)
 {
@@ -1558,20 +1662,28 @@ ephy_node_view_edit (EphyNodeView *view, gboolean remove_if_cancelled)
 	path = rows->data;
 
 	g_object_set (G_OBJECT (view->priv->editable_renderer),
-                      "editable", TRUE,
-                      NULL);
+		      "editable", TRUE,
+		      NULL);
 
 	gtk_tree_view_set_cursor (GTK_TREE_VIEW (view), path,
-                                  view->priv->editable_column,
-                                  TRUE);
+				  view->priv->editable_column,
+				  TRUE);
 
 	view->priv->edited_node = get_node_from_path (view, path);
 	view->priv->remove_if_cancelled = remove_if_cancelled;
 
 	g_list_foreach (rows, (GFunc)gtk_tree_path_free, NULL);
-        g_list_free (rows);
+	g_list_free (rows);
 }
 
+/**
+ * ephy_node_view_is_target:
+ * @view: an #EphyNodeView
+ *
+ * Tells if @view is currently focused.
+ *
+ * Returns: %TRUE if @view is focused
+ **/
 gboolean
 ephy_node_view_is_target (EphyNodeView *view)
 {
@@ -1596,7 +1708,7 @@ filter_visible_func (GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
 
 static GObject *
 ephy_node_view_constructor (GType type, guint n_construct_properties,
-                            GObjectConstructParam *construct_params)
+			    GObjectConstructParam *construct_params)
 
 {
 	GObject *object;
@@ -1605,7 +1717,7 @@ ephy_node_view_constructor (GType type, guint n_construct_properties,
 	GtkTreeSelection *selection;
 
 	object = parent_class->constructor (type, n_construct_properties,
-                                            construct_params);
+					    construct_params);
 	view = EPHY_NODE_VIEW (object);
 	priv = EPHY_NODE_VIEW_GET_PRIVATE (object);
 
@@ -1617,24 +1729,33 @@ ephy_node_view_constructor (GType type, guint n_construct_properties,
 	priv->sortmodel = ephy_tree_model_sort_new (priv->filtermodel);
 	gtk_tree_view_set_model (GTK_TREE_VIEW (object), GTK_TREE_MODEL (priv->sortmodel));
 	g_signal_connect_object (object, "button_press_event",
-			         G_CALLBACK (ephy_node_view_button_press_cb),
-			         view, 0);
+				 G_CALLBACK (ephy_node_view_button_press_cb),
+				 view, 0);
 	g_signal_connect (object, "key_press_event",
 			  G_CALLBACK (ephy_node_view_key_press_cb),
 			  view);
 	g_signal_connect_object (object, "row_activated",
-			         G_CALLBACK (ephy_node_view_row_activated_cb),
-			         view, 0);
+				 G_CALLBACK (ephy_node_view_row_activated_cb),
+				 view, 0);
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (view));
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
 	g_signal_connect_object (G_OBJECT (selection), "changed",
-			         G_CALLBACK (ephy_node_view_selection_changed_cb),
-			         view, 0);
+				 G_CALLBACK (ephy_node_view_selection_changed_cb),
+				 view, 0);
 
 	return object;
 }
 
+/**
+ * ephy_node_view_add_toggle:
+ * @view: an #EphyNodeView widget
+ * @value_func: an #EphyTreeModelNodeValueFunc function to set column values
+ * @data: user_data to be passed to @value_func
+ *
+ * Append a new toggle column to @view with its value set by @value_func which can
+ * receive the optional @data parameter.
+ **/
 void
 ephy_node_view_add_toggle (EphyNodeView *view, EphyTreeModelNodeValueFunc value_func,
 			   gpointer data)
@@ -1653,6 +1774,13 @@ ephy_node_view_add_toggle (EphyNodeView *view, EphyTreeModelNodeValueFunc value_
 	gtk_tree_view_append_column (GTK_TREE_VIEW (view), col);
 }
 
+/**
+ * ephy_node_view_popup:
+ * @view: an #EphyNodeView widget
+ * @menu: a #GtkMenu to be shown
+ *
+ * Triggers the popup of @menu in @view.
+ **/
 void
 ephy_node_view_popup (EphyNodeView *view, GtkWidget *menu)
 {
@@ -1695,12 +1823,23 @@ ephy_node_view_class_init (EphyNodeViewClass *klass)
 	object_class->set_property = ephy_node_view_set_property;
 	object_class->get_property = ephy_node_view_get_property;
 
+	/**
+	* EphyNodeView:root:
+	*
+	* A #gpointer to the root node of the #EphyNode elements of the view.
+	*/
 	g_object_class_install_property (object_class,
 					 PROP_ROOT,
 					 g_param_spec_pointer ("root",
 							       "Root node",
 							       "Root node",
 							       G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_CONSTRUCT_ONLY));
+
+	/**
+	* EphyNodeView:filter:
+	*
+	* An #EphyNodeFilter object to use in the view.
+	*/
 	g_object_class_install_property (object_class,
 					 PROP_FILTER,
 					 g_param_spec_object ("filter",
@@ -1709,6 +1848,14 @@ ephy_node_view_class_init (EphyNodeViewClass *klass)
 							      EPHY_TYPE_NODE_FILTER,
 							      G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
+	/**
+	* EphyNodeView::node-toggled:
+	* @view: the object on which the signal is emitted
+	* @node: the target #EphyNode
+	* @checked: the new value of the toggle column
+	*
+	* Emitted when a row value is toggled, only emitted for toggle columns.
+	*/
 	ephy_node_view_signals[NODE_TOGGLED] =
 		g_signal_new ("node_toggled",
 			      G_OBJECT_CLASS_TYPE (object_class),
@@ -1720,6 +1867,13 @@ ephy_node_view_class_init (EphyNodeViewClass *klass)
 			      2,
 			      G_TYPE_POINTER,
 			      G_TYPE_BOOLEAN);
+	/**
+	* EphyNodeView::node-activated:
+	* @view: the object on which the signal is emitted
+	* @node: the activated #EphyNode
+	*
+	* Emitted when a row is activated.
+	*/
 	ephy_node_view_signals[NODE_ACTIVATED] =
 		g_signal_new ("node_activated",
 			      G_OBJECT_CLASS_TYPE (object_class),
@@ -1730,6 +1884,13 @@ ephy_node_view_class_init (EphyNodeViewClass *klass)
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_POINTER);
+	/**
+	* EphyNodeView::node-selected:
+	* @view: the object on which the signal is emitted
+	* @node: the selected #EphyNode
+	*
+	* Emitted when a row is selected.
+	*/
 	ephy_node_view_signals[NODE_SELECTED] =
 		g_signal_new ("node_selected",
 			      G_OBJECT_CLASS_TYPE (object_class),
@@ -1740,6 +1901,14 @@ ephy_node_view_class_init (EphyNodeViewClass *klass)
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_POINTER);
+	/**
+	* EphyNodeView::node-dropped:
+	* @view: the object on which the signal is emitted
+	* @node: the dropped #EphyNode
+	* @uris: URIs from the dragged data
+	*
+	* Emitted when an #EphyNode is dropped into the #EphyNodeView.
+	*/
 	ephy_node_view_signals[NODE_DROPPED] =
 		g_signal_new ("node_dropped",
 			      G_OBJECT_CLASS_TYPE (object_class),
@@ -1751,6 +1920,14 @@ ephy_node_view_class_init (EphyNodeViewClass *klass)
 			      2,
 			      G_TYPE_POINTER,
 			      G_TYPE_POINTER);
+
+	/**
+	* EphyNodeView::node-middle-clicked:
+	* @view: the object on which the signal is emitted
+	* @node: the clicked #EphyNode
+	*
+	* Emitted when the user middle clicks on a row of the #EphyNodeView.
+	*/
 	ephy_node_view_signals[NODE_MIDDLE_CLICKED] =
 		g_signal_new ("node_middle_clicked",
 			      G_OBJECT_CLASS_TYPE (object_class),
