@@ -889,13 +889,13 @@ cmd_bookmarks_export (GtkAction *action,
 	/* Make a format selection combo & label */
 	label = gtk_label_new_with_mnemonic (_("File f_ormat:"));
 
-	combo = gtk_combo_box_new_text ();
+	combo = gtk_combo_box_text_new ();
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), combo);
 
 	for (format = 0; format < G_N_ELEMENTS (export_formats); ++format)
 	{
-		gtk_combo_box_append_text (GTK_COMBO_BOX (combo),
-					   _(export_formats[format].name));
+		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo),
+					        _(export_formats[format].name));
 	}
 
 	g_object_set_data (G_OBJECT (dialog), "format-combo", combo);
@@ -1688,7 +1688,7 @@ ephy_bookmarks_editor_construct (EphyBookmarksEditor *editor)
 	editor->priv->ui_merge = ui_merge;
 	editor->priv->action_group = action_group;
 
-	hpaned = gtk_hpaned_new ();
+	hpaned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_container_set_border_width (GTK_CONTAINER (hpaned), 0);
 	gtk_box_pack_end (GTK_BOX (editor->priv->main_vbox), hpaned,
 			  TRUE, TRUE, 0);
