@@ -63,9 +63,6 @@ EphyWindow	 *ephy_window_new		  (void);
 EphyWindow	 *ephy_window_new_with_chrome	  (EphyWebViewChrome chrome,
 						   gboolean is_popup);
 
-void		 _ephy_window_set_print_preview	  (EphyWindow *window,
-						   gboolean enabled);
-
 GObject		 *ephy_window_get_ui_manager	  (EphyWindow *window);
 
 GtkWidget	 *ephy_window_get_toolbar	  (EphyWindow *window);
@@ -74,8 +71,6 @@ GtkWidget	 *ephy_window_get_notebook	  (EphyWindow *window);
 
 GtkWidget        *ephy_window_get_find_toolbar    (EphyWindow *window);
 
-GtkWidget	 *ephy_window_get_statusbar	  (EphyWindow *window);
-
 void		  ephy_window_load_url		  (EphyWindow *window,
 						   const char *url);
 
@@ -84,15 +79,9 @@ void		  ephy_window_set_zoom		  (EphyWindow *window,
 
 void		  ephy_window_activate_location	  (EphyWindow *window);
 
-gboolean	  ephy_window_get_is_print_preview(EphyWindow *window);
 
 EphyEmbedEvent	 *ephy_window_get_context_event	  (EphyWindow *window);
 
-void		 _ephy_window_set_context_event	  (EphyWindow *window,
-						   EphyEmbedEvent *event);
-
-void		 _ephy_window_unset_context_event (EphyWindow *window);
-
 G_END_DECLS
 
 #endif
