@@ -30,8 +30,8 @@
 #include "ephy-embed-persist.h"
 #include "ephy-debug.h"
 #include "window-commands.h"
-#include "eel-gconf-extensions.h"
 #include "ephy-prefs.h"
+#include "ephy-settings.h"
 #include "ephy-embed-prefs.h"
 #include "ephy-dialog.h"
 #include "ephy-bookmarks-editor.h"
@@ -313,7 +313,7 @@ window_cmd_file_open (GtkAction *action,
 	dialog = ephy_file_chooser_new (_("Open"),
 					GTK_WIDGET (window),
 					GTK_FILE_CHOOSER_ACTION_OPEN,
-					CONF_STATE_OPEN_DIR,
+					EPHY_PREFS_STATE_OPEN_DIR,
 					EPHY_FILE_FILTER_ALL_SUPPORTED);
 
 	g_signal_connect (dialog, "response",
@@ -343,8 +343,8 @@ window_cmd_file_save_as (GtkAction *action,
 	dialog = ephy_file_chooser_new (_("Save"),
 					GTK_WIDGET (window),
 					GTK_FILE_CHOOSER_ACTION_SAVE,
-					CONF_STATE_SAVE_DIR,
-					EPHY_FILE_FILTER_ALL_SUPPORTED);
+					EPHY_PREFS_STATE_SAVE_DIR,
+					EPHY_FILE_FILTER_ALL);
 
 	gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE);
 
@@ -396,7 +396,8 @@ window_cmd_file_close_window (GtkAction *action,
 
 	notebook = ephy_window_get_notebook (window);
 
-	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_QUIT) &&
+	if (g_settings_get_boolean (EPHY_SETTINGS_LOCKDOWN,
+				    EPHY_PREFS_LOCKDOWN_QUIT) &&
 	    gtk_notebook_get_n_pages (GTK_NOTEBOOK (notebook)) == 1)
 	{
 		return;
@@ -1040,7 +1041,7 @@ window_cmd_help_about (GtkAction *action,
 			       "name", _("GNOME Web Browser"),
 			       "version", VERSION,
 			       "copyright", "Copyright © 2002–2004 Marco Pesenti Gritti\n"
-			                    "Copyright © 2003–2009 The GNOME Web Browser Developers",
+			                    "Copyright © 2003–2010 The GNOME Web Browser Developers",
 			       "artists", artists,
 			       "authors", authors,
 			       "comments", comments,
@@ -1193,7 +1194,45 @@ window_cmd_browse_with_caret (GtkAction *action,
 			      EphyWindow *window)
 {
 	gboolean active;
+	EphyEmbed *embed;
 
+	embed = ephy_embed_container_get_active_child 
+		(EPHY_EMBED_CONTAINER (window));
+	
 	active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
-	eel_gconf_set_boolean (CONF_CARET_BROWSING_ENABLED, active);
+
+	/* FIXME: perhaps a bit of a kludge; we check if there's an
+	 * active embed because we don't want to show the dialog on
+	 * startup when we sync the GtkAction with our GConf
+	 * preference */
+	if (active && embed)
+	{
+		GtkWidget *dialog;
+		int response;
+
+		dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+						 GTK_DIALOG_DESTROY_WITH_PARENT,
+						 GTK_MESSAGE_QUESTION, GTK_BUTTONS_CANCEL,
+						 _("Enable caret browsing mode?"));
+
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+							  _("Pressing F7 turns caret browsing on or off. This feature "
+							    "places a moveable cursor in web pages, allowing you to move "
+							    "around with your keyboard. Do you want to enable caret browsing on?"));
+		gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Enable"), GTK_RESPONSE_ACCEPT);
+		gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
+
+		response = gtk_dialog_run (GTK_DIALOG (dialog));
+
+		gtk_widget_destroy (dialog);
+
+		if (response == GTK_RESPONSE_CANCEL)
+		{
+			gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), FALSE);
+			return;
+		}
+	}
+
+	g_settings_set_boolean (EPHY_SETTINGS_MAIN,
+				EPHY_PREFS_ENABLE_CARET_BROWSING, active);
 }
